@@ -48,19 +48,27 @@ import System.Random.Mersenne.Pure64.Internal
 import System.Random
 import Data.Word
 import Data.Int
-import System.Time
+import Data.Time.Clock
+import Data.Time.Calendar
 import System.CPUTime
 
 -- | Create a PureMT generator from a 'Word64' seed.
 pureMT :: Word64 -> PureMT
 pureMT = mkPureMT . seedBlock . fromIntegral
 
+#if !MIN_VERSION_time(1,6,0)
+diffTimeToPicoseconds :: DiffTime -> Integer
+diffTimeToPicoseconds d =
+    round (1000 * 1000 * 1000 * 1000 * d)
+#endif
+
 -- | Create a new PureMT generator, using the clocktime as the base for the seed.
 newPureMT :: IO PureMT
 newPureMT = do
-    ct             <- getCPUTime
-    (TOD sec psec) <- getClockTime
-    return $ pureMT (fromIntegral $ sec * 1013904242 + psec + ct)
+    ct <- getCPUTime
+    t  <- getCurrentTime
+    let seed = toModifiedJulianDay (utctDay t) + diffTimeToPicoseconds (utctDayTime t) + ct
+    return $ pureMT $ fromIntegral seed
 
 ------------------------------------------------------------------------
 -- System.Random interface.
